@@ -1,6 +1,6 @@
 /* grep.c - main driver file for grep.
    Copyright (C) 1992, 1997, 1998, 1999, 2000, 2001, 2002, 2004,
-   2005 Free Software Foundation, Inc.
+   2005, 2006, 2007, 2008, 2009 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -2182,11 +2182,11 @@ main (int argc, char **argv)
     {
       printf ("%s\n\n", PACKAGE_STRING);
       printf (_("\
-Copyright (C) 2008 Free Software Foundation, Inc.\n"));
-      printf (_("\
+Copyright (C) %s Free Software Foundation, Inc.\n\
 License GPLv3+: GNU GPL version 3 or later <http://gnu.org/licenses/gpl.html>\n\
 This is free software: you are free to change and redistribute it.\n\
-There is NO WARRANTY, to the extent permitted by law.\n"));
+There is NO WARRANTY, to the extent permitted by law.\n"),
+        "2009");
       printf ("\n");
       exit (0);
     }
